<?php
// +----------------------------------------------------------------------
// | VitPHP
// +----------------------------------------------------------------------
// | 版权所有 2018~2021 藁城区创新网络电子商务中心 [ http://www.vitphp.cn ]
// +----------------------------------------------------------------------
// | VitPHP是一款免费开源软件,您可以访问http://www.vitphp.cn/以获得更多细节。
// +----------------------------------------------------------------------


namespace app\mz_nfc\controller\wxapp;

use app\BaseController;
use jwt\JWT;
use think\App;
use think\facade\Cache;
use think\facade\Config;
use think\facade\Db;
use think\facade\Request;

class Base extends BaseController
{
    protected $res = [
        'code' => 0,
        'msg' => 'ok',
        'data' => ''
    ];

    /**
     * Base constructor.
     */
    public function __construct(App $app)
    {
        parent::__construct($app);

        $flag = is_appdue(input('pid'));
        if(!$flag){
            $result = [
                'code' => -1,
                'msg' => '应用已到期',
            ];
            echo json_encode($result);
            exit;
        }
    }

    protected function json()
    {
        return json($this->res);
    }

    /**
     * 获取第几页
     * @param string $key post中页码的key值
     * @return int
     */
    protected function getPage($key='page')
    {
        $page = $this->request->post($key) ?? 0;
        $page = (int)$page;
        return $page ?: 1;
    }

    /**
     * 获取显示条数
     * @param string $key post中显示条数的key值
     * @param int $detail
     * @return int
     */
    protected function getNum($key='num', $detail = 0)
    {
        $detail = $detail ?: 15;
        $num = $this->request->post($key) ?? 0;
        $num = (int)$num;
        $num = $num > 100 ? 100 : $num;
        return $num ?: $detail;
    }

    /**
     * 根据附件，返回可直接查看的url，这个应该放在公共方法里
     * @param $media
     * @return array|string
     */
    protected function getFullMediaUrl($media, $https = true)
    {
        if (!$media) return '';
        $preg = "/http[s]?:\/\/[\w.]+[\w\/]*[\w.]*\??[\w=&\+\%]*/is";
        $mediaUrl = media($media, 'act');
        if (!preg_match($preg, $mediaUrl)) {
            $mediaUrl = $https ? 'https://' . Request::host() . $mediaUrl : Request::domain() . $mediaUrl;
        }

        return $mediaUrl;
    }

    /**
     * 获取token
     * @param $uuid
     * @return string
     */
    protected function getToken($uuid)
    {
        $key = Config::get('admin.jwt.key');
        $expire = Config::get('admin.jwt.expire');

        $payload = array(
            'iss' => Config::get('admin.jwt.iss'), //iss: jwt签发者
            'aud' => Config::get('admin.jwt.aud'), //aud: 接收jwt的一方
            'sub' => Config::get('admin.jwt.sub'), //sub: jwt所面向的用户
            'iat' => time(), //iat: jwt的签发时间
            'exp' => time() + $expire, //jwt的过期时间，这个过期时间必须要大于签发时间
            'nbf' => time(), //nbf: 定义在什么时间之前，该jwt都是不可用的.
            'uuid' => $uuid
        );
        return JWT::encode($payload, $key);
    }

    /**
     * 解密token
     * @return false
     */
    protected function decodeToken()
    {
        $token = Request::header('token');
        if (!$token) return false;

        try {
            $key = Config::get('admin.jwt.key');
            $decoded = JWT::decode($token, $key, array('HS256'));
        } catch (\Exception $e) {
            return false;
        }
        return $decoded->uuid;
    }

    /**
     * 存库之前将表情包转一下
     */
    public function userTextEncode($str)
    {
        if (!is_string($str)) return $str;
        if (!$str || $str == 'undefined') return '';

        $text = json_encode($str); //暴露出unicode
        $text = preg_replace_callback("/(\\\u[ed][0-9a-f]{3})/i", function ($str) {
            return addslashes($str[0]);
        }, $text); //将emoji的unicode留下，其他不动，这里的正则比原答案增加了d，因为我发现我很多emoji实际上是\ud开头的，反而暂时没发现有\ue开头。
        return json_decode($text);
    }

    /**
     * 从库中出来的时候，再将字符串转成表情包
     */
    public function userTextDecode($str)
    {
        $text = json_encode($str); //暴露出unicode
        $text = preg_replace_callback('/\\\\\\\\/i', function ($str) {
            return '\\';
        }, $text); //将两条斜杠变成一条，其他不动
        return json_decode($text);
    }
}