<?php
// +----------------------------------------------------------------------
// | VitPHP
// +----------------------------------------------------------------------
// | 版权所有 2018~2021 藁城区创新网络电子商务中心 [ http://www.vitphp.cn ]
// +----------------------------------------------------------------------
// | VitPHP是一款免费开源软件,您可以访问http://www.vitphp.cn/以获得更多细节。
// +----------------------------------------------------------------------

namespace app\mz_nfc\controller\wxapp;

use app\index\controller\api\AppAttachment;
use think\facade\Db;

class User extends Base
{
    protected $middleware = [
        \app\jiakao\middleware\TokenCheck::class => ['except' => ['']]
    ];

    /**
     * 获取用户信息
     * @return \think\response\Json
     */
    public function info()
    {
        header('Access-Control-Allow-Origin: *');

        $pid = input('pid');
        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['data'] = '请先登录';
            return $this->json();
        }

        $userInfo = $this->getInfoByOpenid($pid, $openid);
        unset($userInfo['openid']);
//        $userInfo['haibao'] = $this->getFullMediaUrl($userInfo['haibao']);
//        $userInfo['skma'] = !empty($userInfo['skma']) ? $this->getFullMediaUrl($userInfo['skma']) : '';
        $this->res['data'] = $userInfo;

        return $this->json();
    }

    public function getInfoByOpenid($pid, $openid)
    {
        $userInfo = Db::name('mz_nfc_user')->where(['openid' => $openid, 'pid' => $pid])->find();
        if ($userInfo) {
            $userInfo['nickname'] = $this->userTextDecode($userInfo['nickname']);
            $userInfo['wifi_count'] = Db::name('mz_nfc_url')->where('uid', $userInfo['id'])->count();
            $userInfo['connect_count'] = Db::name('mz_nfc_url')->where('uid', $userInfo['id'])->sum('lian_num');
//            $userInfo['moni_count'] = Db::name('jiakao_moni')->where('uid', '=', $userInfo['id'])->count();
//            $userInfo['child_count'] = $userInfo['nickname'] ? Db::name('jiakao_user')->where('sid', '=', $userInfo['id'])->count() : 0;
        }

        return $userInfo;
    }

    public function bind()
    {
        $pid = input('pid');
        $code = input('code');
        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['code'] = -1;
            $this->res['data'] = '请先登录';
            return $this->json();
        }
        $userInfo = $this->getInfoByOpenid($pid, $openid);
        $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('code', $code)->find();
        if (!$url) {
            $this->res['code'] = -1;
            $this->res['msg'] = '未找到WIFI信息';
            return $this->json();
        }
        if ($url['uid']) {
            $this->res['code'] = -1;
            $this->res['msg'] = '该WIFI已绑定管理员，不可重复绑定';
            return $this->json();
        }

        Db::name('mz_nfc_url')->where('id', $url['id'])->update([
            'uid' => $userInfo['id'],
            'bd_time' => time()
        ]);
        $this->res['msg'] = '绑定成功';
        return $this->json();
    }

    public function getWifiList()
    {
        $pid = input('pid');
        $page = $this->getPage();
        $num = $this->getNum();

        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['code'] = -1;
            $this->res['data'] = '请先登录';
            return $this->json();
        }
        $userInfo = $this->getInfoByOpenid($pid, $openid);
        $list = Db::name('mz_nfc_url')->where('pid', $pid)->where('uid', '=', $userInfo['id'])->page($page, $num)->order('id desc')->select()->toArray();
        $data = [];
        foreach($list as $item){
            $data[] = [
                'lian_num' => $item['lian_num'],
                'pv' => $item['pv'],
                'haibao' => $this->getFullMediaUrl($item['haibao']),
                'code' => $item['code'],
                'name' => $item['name']
            ];
        }

        $this->res['data'] = $data;
        return json($this->res);
    }

    public function getWifi()
    {
        $pid = input('pid');
        $code = input('code');
        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['code'] = -1;
            $this->res['data'] = '请先登录';
            return $this->json();
        }
        $userInfo = $this->getInfoByOpenid($pid, $openid);
        if($userInfo['is_admin']!=2){
            $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('uid', $userInfo['id'])->where('code', $code)->find();
        }else{
            $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('code', $code)->find();
        }
//        $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('uid', $userInfo['id'])->where('code', $code)->hidden(['id','pid','create_time', 'end_time'])->find();
        if(!$url) {
            $this->res['data'] = [];
            return json($this->res);
        }
        $url['show_wxma'] = $this->getFullMediaUrl($url['wxma']);
        $url['show_wxqun'] = $this->getFullMediaUrl($url['wxqun']);

        $this->res['data'] = $url;
        return json($this->res);
    }

    public function createUrl()
    {
        $pid = input('pid');
        $code = input('code');
        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['code'] = -1;
            $this->res['msg'] = '请先登录';
            return $this->json();
        }
        $userInfo = $this->getInfoByOpenid($pid, $openid);

        $params = [
            'name' => input('name'),
            'wifiid' => input('wifiid'),
            'wifipass' => input('wifipass'),
            'tel' => input('tel'),
            'wxma' => input('wxma'),
            'wxqun' => input('wxqun'),
            'hangye' => input('hangye')
        ];

        if($userInfo['is_admin']!=2){
            unset($params['hangye']);
            $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('uid', $userInfo['id'])->where('code', $code)->find();
        }else{
            $url = Db::name('mz_nfc_url')->where('pid', $pid)->where('code', $code)->find();
        }

        if(!$url) {
            $this->res['code'] = -1;
            $this->res['msg'] = '未知的wifi信息';
            return json($this->res);
        }

        Db::name('mz_nfc_url')->where('id', $url['id'])->update($params);

        $this->res['msg'] = '保存成功';
        return json($this->res);
    }

    public function newUrl()
    {
        $pid = input('pid');
        $openid = $this->decodeToken();
        if (!$openid) {
            $this->res['code'] = -1;
            $this->res['msg'] = '请先登录';
            return $this->json();
        }
        $userInfo = $this->getInfoByOpenid($pid, $openid);

        $params = [
            'pid' => $pid,
            'code' => redom(8, 2),
            'name' => input('name'),
            'wifiid' => input('wifiid'),
            'wifipass' => input('wifipass'),
            'tel' => input('tel'),
            'wxma' => input('wxma'),
            'wxqun' => input('wxqun'),
            'uid' => $userInfo['id']
        ];
        if(!$params['name']){
            $this->res['code'] = -1;
            $this->res['msg'] = '请填写wifi名称';
            return $this->json();
        }

        Db::name('mz_nfc_url')->insert($params);

        $this->res['msg'] = '保存成功';
        return json($this->res);
    }
}